==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/tags/NullCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.NullCheckTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a6185a1afd11cbdf soot_jimple_toolkits_annotation_tags_NullCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$needCheck$709a70e595822131(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$needCheck$709a70e595822131;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
	jboolean	(*needCheck$709a70e595822131)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_NullCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_NullCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs {
	jbyte	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_NullCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_NullCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/tags/NullCheckTag.h <==
// public class soot.jimple.toolkits.annotation.tags.NullCheckTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a6185a1afd11cbdf soot_jimple_toolkits_annotation_tags_NullCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_
#define _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object;

typedef struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$fields_struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$needCheck$709a70e595822131(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$needCheck$709a70e595822131;
extern _jc_method _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
	jboolean	(*needCheck$709a70e595822131)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vmethods	soot_jimple_toolkits_annotation_tags_NullCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs {
    _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_refs	soot_jimple_toolkits_annotation_tags_NullCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs {
	jbyte	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$sub_nonrefs	soot_jimple_toolkits_annotation_tags_NullCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$object {
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$vtype _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_tags_NullCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_tags_NullCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_tags_NullCheckTag_H_ */
